@@ -3,7 +3,8 @@
 
     This file is part of Kleopatra, the KDE keymanager
     Copyright (c) 2007, 2008 Klarälvdalens Datakonsult AB
-    Copyright (c) 2016 Intevation GmbH
+    Copyright (c) 2016 by Bundesamt für Sicherheit in der Informationstechnik
+    Software engineering by Intevation GmbH
 
     Kleopatra is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -35,6 +36,7 @@
 
 #include "importcertificatescommand.h"
 #include "importcertificatescommand_p.h"
+#include "certifycertificatecommand.h"
 #include "kleopatra_debug.h"
 
 #include <Libkleo/KeyListSortFilterProxyModel>
@@ -55,6 +57,7 @@
 #include <KMessageBox>
 
 #include <QByteArray>
+#include <QEventLoop>
 #include <QString>
 #include <QWidget>
 #include <QTreeView>
@@ -87,7 +90,7 @@ public:
 
     ~ImportResultProxyModel() {}
 
-    ImportResultProxyModel *clone() const Q_DECL_OVERRIDE
+    ImportResultProxyModel *clone() const override
     {
         // compiler-generated copy ctor is fine!
         return new ImportResultProxyModel(*this);
@@ -100,7 +103,7 @@ public:
     }
 
 protected:
-    QVariant data(const QModelIndex &index, int role) const Q_DECL_OVERRIDE
+    QVariant data(const QModelIndex &index, int role) const override
     {
         if (!index.isValid() || role != Qt::ToolTipRole) {
             return AbstractKeyListSortFilterProxyModel::data(index, role);
@@ -121,7 +124,7 @@ protected:
             return Formatting::importMetaData(*it, rv);
         }
     }
-    bool filterAcceptsRow(int source_row, const QModelIndex &source_parent) const Q_DECL_OVERRIDE
+    bool filterAcceptsRow(int source_row, const QModelIndex &source_parent) const override
     {
         //
         // 0. Keep parents of matching children:
@@ -324,8 +327,71 @@ static QString make_message_report(const std::vector<ImportResult> &res, const Q
                 "<table width=\"100%\">%1</table></qt>", make_report(res, i18n("Totals")));
 }
 
+// Returns false on error, true if please certify was shown.
+bool ImportCertificatesCommand::Private::showPleaseCertify(const GpgME::Import &imp)
+{
+    const char *fpr = imp.fingerprint();
+    if (!fpr) {
+        // WTF
+        qCWarning(KLEOPATRA_LOG) << "Import without fingerprint";
+        return false;
+    }
+    // Exactly one public key imported. Let's see if it is openpgp. We are async here so
+    // we can just fetch it.
+
+    auto ctx = GpgME::Context::createForProtocol(GpgME::OpenPGP);
+    if (!ctx) {
+        // WTF
+        qCWarning(KLEOPATRA_LOG) << "Failed to create OpenPGP proto";
+        return false;
+    }
+    GpgME::Error err;
+    auto key = ctx->key(fpr, err, false);
+    delete ctx;
+
+    if (key.isNull() || err) {
+        // No such key most likely not OpenPGP
+        return false;
+    }
+
+    for (const auto &uid: key.userIDs()) {
+        if (uid.validity() >= GpgME::UserID::Marginal) {
+            // Already marginal so don't bug the user
+            return false;
+        }
+    }
+
+    const QStringList suggestions = QStringList() << i18n("A phone call to the person.")
+        << i18n("Using a business card.")
+        << i18n("Confirming it on a trusted website.");
+
+    auto sel = KMessageBox::questionYesNo(parentWidgetOrView(),
+                i18n("In order to mark the certificate as valid (green) it needs to be certified.") + QStringLiteral("<br>") +
+                i18n("Certifying means that you check the Fingerprint.") + QStringLiteral("<br>") +
+                i18n("Some suggestions to do this are:") +
+                QStringLiteral("<li><ul>%1").arg(suggestions.join(QStringLiteral("</ul><ul>"))) +
+                QStringLiteral("</ul></li>") +
+                i18n("Do you wish to start this process now?"),
+                i18nc("@title", "You have imported a new certificate (public key)"),
+                KStandardGuiItem::yes(), KStandardGuiItem::no(), QStringLiteral("CertifyQuestion"));
+    if (sel == KMessageBox::Yes) {
+        QEventLoop loop;
+        auto cmd = new Commands::CertifyCertificateCommand(key);
+        cmd->setParentWidget(parentWidgetOrView());
+        loop.connect(cmd, SIGNAL(finished()), SLOT(quit()));
+        QMetaObject::invokeMethod(cmd, "start", Qt::QueuedConnection);
+        loop.exec();
+    }
+    return true;
+}
+
 void ImportCertificatesCommand::Private::showDetails(QWidget *parent, const std::vector<ImportResult> &res, const QStringList &ids)
 {
+    if (res.size() == 1 && res[0].numImported() == 1 && res[0].imports().size() == 1) {
+        if (showPleaseCertify(res[0].imports()[0])) {
+            return;
+        }
+    }
     if (parent) {
         setImportResultProxyModel(res, ids);
         KMessageBox::information(parent, make_message_report(res, ids), i18n("Certificate Import Result"));
@@ -336,8 +402,7 @@ void ImportCertificatesCommand::Private::showDetails(QWidget *parent, const std:
 
 void ImportCertificatesCommand::Private::showDetails(const std::vector<ImportResult> &res, const QStringList &ids)
 {
-    setImportResultProxyModel(res, ids);
-    information(make_message_report(res, ids), i18n("Certificate Import Result"));
+    showDetails(parentWidgetOrView(), res, ids);
 }
 
 static QString make_error_message(const Error &err, const QString &id)
@@ -441,6 +506,7 @@ void ImportCertificatesCommand::Private::tryToFinish()
                 }
 
                 QStringList uids;
+                uids.reserve(toTrustOwner.userIDs().size());
                 Q_FOREACH (const UserID &uid, toTrustOwner.userIDs()) {
                     uids << Formatting::prettyNameAndEMail(uid);
                 }
