@@ -3,7 +3,8 @@
 
     This file is part of Kleopatra, the KDE keymanager
     Copyright (c) 2008 Klarälvdalens Datakonsult AB
-                  2016 Intevation GmbH
+                  2016 by Bundesamt für Sicherheit in der Informationstechnik
+    Software engineering by Intevation GmbH
 
     Kleopatra is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -124,7 +125,7 @@ void AutoDecryptVerifyFilesController::Private::schedule()
     }
     if (!m_runningTask) {
         kleo_assert(m_runnableTasks.empty());
-        Q_FOREACH (const std::shared_ptr<const DecryptVerifyResult> &i, m_results) {
+        for (const std::shared_ptr<const DecryptVerifyResult> &i : qAsConst(m_results)) {
             Q_EMIT q->verificationResult(i->verificationResult());
         }
     }
@@ -364,7 +365,6 @@ void AutoDecryptVerifyFilesController::cancel()
 void AutoDecryptVerifyFilesController::doTaskDone(const Task *task, const std::shared_ptr<const Task::Result> &result)
 {
     assert(task);
-    assert(task == d->m_runningTask.get());
     Q_UNUSED(task);
 
     // We could just delete the tasks here, but we can't use
