@@ -2,7 +2,8 @@
 
     This file is part of Kleopatra, the KDE keymanager
     Copyright (c) 2009 Klarälvdalens Datakonsult AB
-                  2016 Intevation GmbH
+                  2016 by Bundesamt für Sicherheit in der Informationstechnik
+    Software engineering by Intevation GmbH
 
     Kleopatra is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -130,7 +131,7 @@ public Q_SLOTS:
     }
 
 protected:
-    void paintEvent(QPaintEvent *) Q_DECL_OVERRIDE {
+    void paintEvent(QPaintEvent *) override {
         QStylePainter p(this);
         p.setPen(palette().color(QPalette::Text));
         QStyleOptionComboBox opt;
