@@ -2,7 +2,8 @@
 
     This file is part of Kleopatra, the KDE keymanager
     Copyright (c) 2009 Klarälvdalens Datakonsult AB
-                  2016 Intevation GmbH
+    2016 by Bundesamt für Sicherheit in der Informationstechnik
+    Software engineering by Intevation GmbH
 
     Kleopatra is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -44,6 +45,7 @@
 #include <KMessageBox>
 
 #include "kleopatra_debug.h"
+#include <utils/gnupg-helper.h>
 
 #include <Libkleo/FileNameRequester>
 #include <QVBoxLayout>
@@ -77,6 +79,7 @@ class SigEncPage: public QWizardPage
 public:
     explicit SigEncPage(QWidget *parent = nullptr)
         : QWizardPage(parent),
+          mParent((SignEncryptFilesWizard *) parent),
           mWidget(new SignEncryptWidget),
           mOutLayout(new QVBoxLayout),
           mArchive(false),
@@ -114,17 +117,17 @@ public:
         setMinimumHeight(300);
     }
 
-    bool isComplete() const Q_DECL_OVERRIDE
+    bool isComplete() const override
     {
         return !mWidget->currentOp().isNull();
     }
 
-    int nextId() const Q_DECL_OVERRIDE
+    int nextId() const override
     {
         return ResultPageId;
     }
 
-    void initializePage() Q_DECL_OVERRIDE
+    void initializePage() override
     {
         setCommitPage(true);
     }
@@ -146,7 +149,7 @@ public:
         }
     }
 
-    bool validatePage() Q_DECL_OVERRIDE
+    bool validatePage() override
     {
         bool sign = !mWidget->signKey().isNull();
         bool encrypt = !mWidget->selfKey().isNull() || !mWidget->recipients().empty();
@@ -283,10 +286,27 @@ public:
 private Q_SLOTS:
     void updateCommitButton(const QString &label)
     {
+        auto btn = mParent->button(QWizard::CommitButton);
         if (!label.isEmpty()) {
-            setButtonText(QWizard::CommitButton, label);
+            btn->setText(label);
+            if (Kleo::gpgComplianceP("de-vs")) {
+                bool de_vs = mWidget->isDeVsAndValid();
+                btn->setIcon(QIcon::fromTheme(de_vs
+                                             ? "security-high"
+                                             : "security-medium"));
+                btn->setStyleSheet(de_vs
+                                   ? "background-color: lime"
+                                   : "background-color: red");
+                mParent->setLabelText(de_vs
+                                      ? i18nc("VS-conforming is a German standard for restricted documents for which special restrictions about algorithms apply.  The string states that all cryptographic operations necessary for the communication are compliant with that.",
+                                              "VS-compliant communication possible.")
+                                      : i18nc("VS-conforming is a German standard for restricted documents for which special restrictions about algorithms apply.  The string states that all cryptographic operations necessary for the communication are compliant with that.",
+                                              "VS-compliant communication not possible."));
+            }
         } else {
-            setButtonText(QWizard::CommitButton, i18n("Next"));
+            btn->setText(i18n("Next"));
+            btn->setIcon(QIcon());
+            btn->setStyleSheet("");
         }
         Q_EMIT completeChanged();
     }
@@ -323,6 +343,7 @@ private Q_SLOTS:
     }
 
 private:
+    SignEncryptFilesWizard *mParent;
     SignEncryptWidget *mWidget;
     QMap <int, QString> mOutNames;
     QMap <int, QWidget *> mRequester;
@@ -336,15 +357,24 @@ private:
 class ResultPage : public NewResultPage
 {
     Q_OBJECT
+
 public:
     explicit ResultPage(QWidget *parent = nullptr)
-        : NewResultPage(parent)
+        : NewResultPage(parent),
+          mParent((SignEncryptFilesWizard *) parent)
     {
         setTitle(i18nc("@title", "Results"));
         setSubTitle(i18nc("@title",
                           "Status and progress of the crypto operations is shown here."));
     }
 
+    void initializePage() override
+    {
+        mParent->setLabelText(QString());
+    }
+
+private:
+    SignEncryptFilesWizard *mParent;
 };
 
 SignEncryptFilesWizard::SignEncryptFilesWizard(QWidget *parent, Qt::WindowFlags f)
@@ -354,6 +384,7 @@ SignEncryptFilesWizard::SignEncryptFilesWizard(QWidget *parent, Qt::WindowFlags
     , mEncryptionUserMutable(false)
     , mEncryptionPreset(false)
 {
+    bool de_vs = Kleo::gpgComplianceP("de-vs");
 #ifdef Q_OS_WIN
     // Enforce modern style to avoid vista style uglyness.
     setWizardStyle(QWizard::ModernStyle);
@@ -366,9 +397,22 @@ SignEncryptFilesWizard::SignEncryptFilesWizard(QWidget *parent, Qt::WindowFlags
     setPage(SigEncPageId, mSigEncPage);
     setPage(ResultPageId, mResultPage);
     setOptions(QWizard::IndependentPages |
+               (de_vs ? QWizard::HaveCustomButton1 : (QWizard::WizardOption) 0) |
                QWizard::NoBackButtonOnLastPage |
                QWizard::NoBackButtonOnStartPage);
 
+    if (de_vs) {
+        /* We use a custom button to display a label next to the
+           buttons.  */
+        mLabel = button(QWizard::CustomButton1);
+        /* We style the button so that it looks and acts like a
+           label.  */
+        mLabel->setStyleSheet("border: none");
+        mLabel->setFocusPolicy(Qt::NoFocus);
+    } else {
+        mLabel = NULL;
+    }
+
     KConfigGroup cfgGroup(KSharedConfig::openConfig(), "SignEncryptFilesWizard");
     const QByteArray geom = cfgGroup.readEntry("geometry", QByteArray());
     if (!geom.isEmpty()) {
@@ -377,6 +421,13 @@ SignEncryptFilesWizard::SignEncryptFilesWizard(QWidget *parent, Qt::WindowFlags
     }
 }
 
+void SignEncryptFilesWizard::setLabelText(const QString &label) const
+{
+    if (mLabel) {
+        mLabel->setText(label);
+    }
+}
+
 void SignEncryptFilesWizard::slotCurrentIdChanged(int id)
 {
     if (id == ResultPageId) {
