@@ -3,6 +3,8 @@
 
     This file is part of Kleopatra, the KDE keymanager
     Copyright (c) 2009 Klarälvdalens Datakonsult AB
+    2016 by Bundesamt für Sicherheit in der Informationstechnik
+    Software engineering by Intevation GmbH
 
     Kleopatra is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -100,6 +102,8 @@ public:
     QVector<GpgME::Key> resolvedSigners() const;
     bool encryptSymmetric() const;
 
+    void setLabelText(const QString &label) const;
+
 Q_SIGNALS:
     void operationPrepared();
 
@@ -109,6 +113,7 @@ private Q_SLOTS:
 private:
     SigEncPage *mSigEncPage;
     ResultPage *mResultPage;
+    QAbstractButton *mLabel;
     bool mSigningPreset,
          mSigningUserMutable,
          mEncryptionUserMutable,
