@@ -193,7 +193,7 @@ unsigned int KDLogTextWidget::historySize() const
 */
 QString KDLogTextWidget::text() const
 {
-    return lines().join(QStringLiteral("\n"));
+    return lines().join(QLatin1Char('\n'));
 }
 
 /*!
@@ -207,7 +207,7 @@ QString KDLogTextWidget::text() const
 void KDLogTextWidget::setLines(const QStringList &l)
 {
     clear();
-    Q_FOREACH (const QString &s, l) {
+    for (const QString &s : l) {
         message(s);
     }
 }
