@@ -86,9 +86,9 @@ public:
         return m_isTemporary;
     }
 
-    void setHierarchicalView(bool hierarchical) Q_DECL_OVERRIDE;
-    void setStringFilter(const QString &filter) Q_DECL_OVERRIDE;
-    void setKeyFilter(const std::shared_ptr<KeyFilter> &filter) Q_DECL_OVERRIDE;
+    void setHierarchicalView(bool hierarchical) override;
+    void setStringFilter(const QString &filter) override;
+    void setKeyFilter(const std::shared_ptr<KeyFilter> &filter) override;
 
     QString title() const
     {
@@ -125,7 +125,7 @@ public:
 
     void saveTo(KConfigGroup &group) const;
 
-    Page *clone() const Q_DECL_OVERRIDE
+    Page *clone() const override
     {
         return new Page(*this);
     }
@@ -909,7 +909,7 @@ void TabWidget::loadViews(const KConfig *config)
     if (config) {
         QStringList groupList = extractViewGroups(config);
         groupList.sort();
-        Q_FOREACH (const QString &group, groupList) {
+        for (const QString &group : qAsConst(groupList)) {
             const KConfigGroup kcg(config, group);
             if (!KCONFIG_DELETEGROUP_BROKEN || kcg.readEntry("magic", 0U) == 0xFA1AFE1U) {
                 addView(kcg);
